bunnyhop

package module
v0.0.0-...-ecff562 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 15, 2018 License: GPL-3.0 Imports: 3 Imported by: 0

README

bunnyhop

GoDoc

A small, portable library to check if an IP is in use on a local network. Read Godoc for usage. Example found in the example directory.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func IPInUse

func IPInUse(iface, ip string, timeout time.Duration) (bool, error)

IPInUse defines a generic function to check to see if an IP is in use on a given network.

Types

This section is empty.

Directories

Path Synopsis

Jump to